# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sparkworks_client
from sparkworks_client.api.participatory_sensing_api_api import ParticipatorySensingAPIApi  # noqa: E501
from sparkworks_client.rest import ApiException


class TestParticipatorySensingAPIApi(unittest.TestCase):
    """ParticipatorySensingAPIApi unit test stubs"""

    def setUp(self):
        self.api = sparkworks_client.api.participatory_sensing_api_api.ParticipatorySensingAPIApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_ps_resource(self):
        """Test case for create_ps_resource

        Create a Participatory Sensing Resource with an autogenerated uri  # noqa: E501
        """
        pass

    def test_delete_ps_resource(self):
        """Test case for delete_ps_resource

        Delete a Participatory Sensing Resource  # noqa: E501
        """
        pass

    def test_publish_ps_data(self):
        """Test case for publish_ps_data

        Publish data to a Participatory Sensing Resource.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ResourceDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'controls': 'str',
        'created_by': 'str',
        'created_date': 'datetime',
        'deleted': 'bool',
        'gateway_system_name': 'str',
        'group_uuid': 'str',
        'last_modified_by': 'str',
        'last_modified_date': 'datetime',
        'phenomenon_uuid': 'str',
        'system_name': 'str',
        'type': 'str',
        'unit_uuid': 'str',
        'user_friendly_name': 'str',
        'uuid': 'str'
    }

    attribute_map = {
        'controls': 'controls',
        'created_by': 'createdBy',
        'created_date': 'createdDate',
        'deleted': 'deleted',
        'gateway_system_name': 'gatewaySystemName',
        'group_uuid': 'groupUuid',
        'last_modified_by': 'lastModifiedBy',
        'last_modified_date': 'lastModifiedDate',
        'phenomenon_uuid': 'phenomenonUuid',
        'system_name': 'systemName',
        'type': 'type',
        'unit_uuid': 'unitUuid',
        'user_friendly_name': 'userFriendlyName',
        'uuid': 'uuid'
    }

    def __init__(self, controls=None, created_by=None, created_date=None, deleted=None, gateway_system_name=None, group_uuid=None, last_modified_by=None, last_modified_date=None, phenomenon_uuid=None, system_name=None, type=None, unit_uuid=None, user_friendly_name=None, uuid=None):  # noqa: E501
        """ResourceDTO - a model defined in Swagger"""  # noqa: E501

        self._controls = None
        self._created_by = None
        self._created_date = None
        self._deleted = None
        self._gateway_system_name = None
        self._group_uuid = None
        self._last_modified_by = None
        self._last_modified_date = None
        self._phenomenon_uuid = None
        self._system_name = None
        self._type = None
        self._unit_uuid = None
        self._user_friendly_name = None
        self._uuid = None
        self.discriminator = None

        if controls is not None:
            self.controls = controls
        if created_by is not None:
            self.created_by = created_by
        if created_date is not None:
            self.created_date = created_date
        if deleted is not None:
            self.deleted = deleted
        if gateway_system_name is not None:
            self.gateway_system_name = gateway_system_name
        if group_uuid is not None:
            self.group_uuid = group_uuid
        if last_modified_by is not None:
            self.last_modified_by = last_modified_by
        if last_modified_date is not None:
            self.last_modified_date = last_modified_date
        if phenomenon_uuid is not None:
            self.phenomenon_uuid = phenomenon_uuid
        if system_name is not None:
            self.system_name = system_name
        if type is not None:
            self.type = type
        if unit_uuid is not None:
            self.unit_uuid = unit_uuid
        if user_friendly_name is not None:
            self.user_friendly_name = user_friendly_name
        if uuid is not None:
            self.uuid = uuid

    @property
    def controls(self):
        """Gets the controls of this ResourceDTO.  # noqa: E501


        :return: The controls of this ResourceDTO.  # noqa: E501
        :rtype: str
        """
        return self._controls

    @controls.setter
    def controls(self, controls):
        """Sets the controls of this ResourceDTO.


        :param controls: The controls of this ResourceDTO.  # noqa: E501
        :type: str
        """

        self._controls = controls

    @property
    def created_by(self):
        """Gets the created_by of this ResourceDTO.  # noqa: E501


        :return: The created_by of this ResourceDTO.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this ResourceDTO.


        :param created_by: The created_by of this ResourceDTO.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def created_date(self):
        """Gets the created_date of this ResourceDTO.  # noqa: E501


        :return: The created_date of this ResourceDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this ResourceDTO.


        :param created_date: The created_date of this ResourceDTO.  # noqa: E501
        :type: datetime
        """

        self._created_date = created_date

    @property
    def deleted(self):
        """Gets the deleted of this ResourceDTO.  # noqa: E501


        :return: The deleted of this ResourceDTO.  # noqa: E501
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this ResourceDTO.


        :param deleted: The deleted of this ResourceDTO.  # noqa: E501
        :type: bool
        """

        self._deleted = deleted

    @property
    def gateway_system_name(self):
        """Gets the gateway_system_name of this ResourceDTO.  # noqa: E501


        :return: The gateway_system_name of this ResourceDTO.  # noqa: E501
        :rtype: str
        """
        return self._gateway_system_name

    @gateway_system_name.setter
    def gateway_system_name(self, gateway_system_name):
        """Sets the gateway_system_name of this ResourceDTO.


        :param gateway_system_name: The gateway_system_name of this ResourceDTO.  # noqa: E501
        :type: str
        """

        self._gateway_system_name = gateway_system_name

    @property
    def group_uuid(self):
        """Gets the group_uuid of this ResourceDTO.  # noqa: E501


        :return: The group_uuid of this ResourceDTO.  # noqa: E501
        :rtype: str
        """
        return self._group_uuid

    @group_uuid.setter
    def group_uuid(self, group_uuid):
        """Sets the group_uuid of this ResourceDTO.


        :param group_uuid: The group_uuid of this ResourceDTO.  # noqa: E501
        :type: str
        """

        self._group_uuid = group_uuid

    @property
    def last_modified_by(self):
        """Gets the last_modified_by of this ResourceDTO.  # noqa: E501


        :return: The last_modified_by of this ResourceDTO.  # noqa: E501
        :rtype: str
        """
        return self._last_modified_by

    @last_modified_by.setter
    def last_modified_by(self, last_modified_by):
        """Sets the last_modified_by of this ResourceDTO.


        :param last_modified_by: The last_modified_by of this ResourceDTO.  # noqa: E501
        :type: str
        """

        self._last_modified_by = last_modified_by

    @property
    def last_modified_date(self):
        """Gets the last_modified_date of this ResourceDTO.  # noqa: E501


        :return: The last_modified_date of this ResourceDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._last_modified_date

    @last_modified_date.setter
    def last_modified_date(self, last_modified_date):
        """Sets the last_modified_date of this ResourceDTO.


        :param last_modified_date: The last_modified_date of this ResourceDTO.  # noqa: E501
        :type: datetime
        """

        self._last_modified_date = last_modified_date

    @property
    def phenomenon_uuid(self):
        """Gets the phenomenon_uuid of this ResourceDTO.  # noqa: E501


        :return: The phenomenon_uuid of this ResourceDTO.  # noqa: E501
        :rtype: str
        """
        return self._phenomenon_uuid

    @phenomenon_uuid.setter
    def phenomenon_uuid(self, phenomenon_uuid):
        """Sets the phenomenon_uuid of this ResourceDTO.


        :param phenomenon_uuid: The phenomenon_uuid of this ResourceDTO.  # noqa: E501
        :type: str
        """

        self._phenomenon_uuid = phenomenon_uuid

    @property
    def system_name(self):
        """Gets the system_name of this ResourceDTO.  # noqa: E501


        :return: The system_name of this ResourceDTO.  # noqa: E501
        :rtype: str
        """
        return self._system_name

    @system_name.setter
    def system_name(self, system_name):
        """Sets the system_name of this ResourceDTO.


        :param system_name: The system_name of this ResourceDTO.  # noqa: E501
        :type: str
        """

        self._system_name = system_name

    @property
    def type(self):
        """Gets the type of this ResourceDTO.  # noqa: E501


        :return: The type of this ResourceDTO.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ResourceDTO.


        :param type: The type of this ResourceDTO.  # noqa: E501
        :type: str
        """
        allowed_values = ["Actuator", "Sensor", "Undefined"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def unit_uuid(self):
        """Gets the unit_uuid of this ResourceDTO.  # noqa: E501


        :return: The unit_uuid of this ResourceDTO.  # noqa: E501
        :rtype: str
        """
        return self._unit_uuid

    @unit_uuid.setter
    def unit_uuid(self, unit_uuid):
        """Sets the unit_uuid of this ResourceDTO.


        :param unit_uuid: The unit_uuid of this ResourceDTO.  # noqa: E501
        :type: str
        """

        self._unit_uuid = unit_uuid

    @property
    def user_friendly_name(self):
        """Gets the user_friendly_name of this ResourceDTO.  # noqa: E501


        :return: The user_friendly_name of this ResourceDTO.  # noqa: E501
        :rtype: str
        """
        return self._user_friendly_name

    @user_friendly_name.setter
    def user_friendly_name(self, user_friendly_name):
        """Sets the user_friendly_name of this ResourceDTO.


        :param user_friendly_name: The user_friendly_name of this ResourceDTO.  # noqa: E501
        :type: str
        """

        self._user_friendly_name = user_friendly_name

    @property
    def uuid(self):
        """Gets the uuid of this ResourceDTO.  # noqa: E501


        :return: The uuid of this ResourceDTO.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this ResourceDTO.


        :param uuid: The uuid of this ResourceDTO.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResourceDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResourceDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class AParticipatorySensingResourceRequestAPIModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'group_uuid': 'str',
        'name': 'str',
        'observes': 'str',
        'uom': 'str'
    }

    attribute_map = {
        'group_uuid': 'groupUuid',
        'name': 'name',
        'observes': 'observes',
        'uom': 'uom'
    }

    def __init__(self, group_uuid=None, name=None, observes=None, uom=None):  # noqa: E501
        """AParticipatorySensingResourceRequestAPIModel - a model defined in Swagger"""  # noqa: E501

        self._group_uuid = None
        self._name = None
        self._observes = None
        self._uom = None
        self.discriminator = None

        if group_uuid is not None:
            self.group_uuid = group_uuid
        self.name = name
        self.observes = observes
        self.uom = uom

    @property
    def group_uuid(self):
        """Gets the group_uuid of this AParticipatorySensingResourceRequestAPIModel.  # noqa: E501

        The UUID of the Group of the Resource  # noqa: E501

        :return: The group_uuid of this AParticipatorySensingResourceRequestAPIModel.  # noqa: E501
        :rtype: str
        """
        return self._group_uuid

    @group_uuid.setter
    def group_uuid(self, group_uuid):
        """Sets the group_uuid of this AParticipatorySensingResourceRequestAPIModel.

        The UUID of the Group of the Resource  # noqa: E501

        :param group_uuid: The group_uuid of this AParticipatorySensingResourceRequestAPIModel.  # noqa: E501
        :type: str
        """

        self._group_uuid = group_uuid

    @property
    def name(self):
        """Gets the name of this AParticipatorySensingResourceRequestAPIModel.  # noqa: E501

        The Resource name  # noqa: E501

        :return: The name of this AParticipatorySensingResourceRequestAPIModel.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AParticipatorySensingResourceRequestAPIModel.

        The Resource name  # noqa: E501

        :param name: The name of this AParticipatorySensingResourceRequestAPIModel.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def observes(self):
        """Gets the observes of this AParticipatorySensingResourceRequestAPIModel.  # noqa: E501

        The name of a Spark Works platform property assigned to the Resource to describe the observed property  # noqa: E501

        :return: The observes of this AParticipatorySensingResourceRequestAPIModel.  # noqa: E501
        :rtype: str
        """
        return self._observes

    @observes.setter
    def observes(self, observes):
        """Sets the observes of this AParticipatorySensingResourceRequestAPIModel.

        The name of a Spark Works platform property assigned to the Resource to describe the observed property  # noqa: E501

        :param observes: The observes of this AParticipatorySensingResourceRequestAPIModel.  # noqa: E501
        :type: str
        """
        if observes is None:
            raise ValueError("Invalid value for `observes`, must not be `None`")  # noqa: E501

        self._observes = observes

    @property
    def uom(self):
        """Gets the uom of this AParticipatorySensingResourceRequestAPIModel.  # noqa: E501

        The Unit of Measurement of the Resource  # noqa: E501

        :return: The uom of this AParticipatorySensingResourceRequestAPIModel.  # noqa: E501
        :rtype: str
        """
        return self._uom

    @uom.setter
    def uom(self, uom):
        """Sets the uom of this AParticipatorySensingResourceRequestAPIModel.

        The Unit of Measurement of the Resource  # noqa: E501

        :param uom: The uom of this AParticipatorySensingResourceRequestAPIModel.  # noqa: E501
        :type: str
        """
        if uom is None:
            raise ValueError("Invalid value for `uom`, must not be `None`")  # noqa: E501

        self._uom = uom

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AParticipatorySensingResourceRequestAPIModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AParticipatorySensingResourceRequestAPIModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
